@@ -1,16 +1,3 @@
-=head1 NAME
-
-AudioFile::Info::MP3::Info - Perl extension to get info from MP3 files.
-
-=head1 DESCRIPTION
-
-This is a plugin for AudioFile::Info which uses MP3::Info to get
-data about MP3 files.
-
-See L<AudioFile::Info> for more details.
-
-=cut
-
 package AudioFile::Info::MP3::Info;
 
 use 5.006;
@@ -20,7 +7,7 @@ use Carp;
 
 use MP3::Info;
 
-our $VERSION = '1.5.1';
+our $VERSION = sprintf "%d.%02d", '$Revision: 1.1.1.1 $ ' =~ /(\d+)\.(\d+)/;
 
 my %data = (artist => 'ARTIST',
             title  => 'TITLE',
@@ -55,12 +42,16 @@ sub AUTOLOAD {
 1;
 __END__
 
-=head1 METHODS
+=head1 NAME
 
-=head2 new
+AudioFile::Info::MP3::Info - Perl extension to get info from MP3 files.
 
-Creates a new object of class AudioFile::Info::MP3::Info. Usually called
-by AudioFile::Info::new.
+=head1 DESCRIPTION
+
+This is a plugin for AudioFile::Info which uses MP3::ID3Lib to get
+data about MP files.
+
+See L<AudioFile::Info> for more details.
 
 =head1 AUTHOR
 
@@ -71,6 +62,6 @@ Dave Cross, E<lt>dave@dave.org.ukE<gt>
 Copyright 2003 by Dave Cross
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+it under the same terms as Perl itself. 
 
 =cut
